Python Module Index — Django Comments 1.5 documentation

### Navigation

- index
- modules |
- Django Comments 1.5 documentation »

# Python Module Index

d

| d |
| `django_comments` | The package formerly known as "django.contrib.comments".
| `django_comments.forms` | Forms for dealing with the comment model.
| `django_comments.models` | The comment models
| `django_comments.moderation` | Support for automatic comment moderation.
| `django_comments.signals` | Signals sent by the comment module.

### Navigation

- index
- modules |
- Django Comments 1.5 documentation »